@@ -74,8 +74,8 @@ bool setupScene(char *stagename)
 	
 	char sceneLine[1024];
 
-	if (!engine.loadData("data/ending"))
-		graphics.showErrorAndExit("Couldn't load cutscene data file (%s)", "data/ending");
+	if (!engine.loadData(_("data/ending")))
+		graphics.showErrorAndExit("Couldn't load cutscene data file (%s)", _("data/ending"));
 
 	char *line = strtok((char*)engine.dataBuffer, "\n");
 	int i = 0;
@@ -199,6 +199,8 @@ void showScene(bool allowSkip)
 				break;
 			}
 		}
+
+		SDL_Delay(16);
 	}
 	
 	SDL_FillRect(graphics.screen, NULL, graphics.black);
