@@ -289,6 +289,15 @@ enum {
 #define MAP_LAVAANIM	214
 #define MAP_TOPLAYER	221
 
+#define MAP_AIR_WALL_1	127
+#define MAP_AIR_WALL_2	129
+#define MAP_AIR_CEILING_1	242
+#define MAP_AIR_WALL_3	243
+#define MAP_AIR_WALL_4	244
+#define MAP_AIR_CEILING_2	247
+
+#define MAP_WATER_WALL	246
+
 #define MAP_SHAKEAMOUNT	2
 
 /* ########### mia stuff ############## */
