@@ -36,7 +36,7 @@ void skipBossMission()
 		game.stagesCleared = 11;
 		SDL_FillRect(graphics.screen, NULL, graphics.black);
 		graphics.delay(250);
-		graphics.drawString("You got the Aqua Lung!", 320, 420, TXT_CENTERED, graphics.screen);
+		graphics.drawString(_("You got the Aqua Lung!"), 320, 420, TXT_CENTERED, graphics.screen);
 		graphics.delay(2000);
 		SDL_FillRect(graphics.screen, NULL, graphics.black);
 	}
@@ -48,7 +48,7 @@ void skipBossMission()
 		game.stagesCleared = 16;
 		SDL_FillRect(graphics.screen, NULL, graphics.black);
 		graphics.delay(250);
-		graphics.drawString("You got the Jet Pack!", 320, 420, TXT_CENTERED, graphics.screen);
+		graphics.drawString(_("You got the Jet Pack!"), 320, 420, TXT_CENTERED, graphics.screen);
 		graphics.delay(2000);
 		SDL_FillRect(graphics.screen, NULL, graphics.black);
 	}
@@ -220,7 +220,7 @@ void showMissionClear()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, "%s", "Rescue %d MIAs");
+		sprintf(message, "%s", _("Rescue %d MIAs"));
 		sprintf(message, message, map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_RIGHT, graphics.background);
 
@@ -233,7 +233,7 @@ void showMissionClear()
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_LEFT, graphics.background);
+			graphics.drawString(_("Completed"), col2, y, TXT_LEFT, graphics.background);
 		}
 	}
 
@@ -251,11 +251,11 @@ void showMissionClear()
 		
 		if ((game.skill < 3) &&  (strstr(objective->description, "L.R.T.S.")) && (!gameData.completedWorld))
 		{
-			graphics.drawString("???? ???????? ????", col1, y, TXT_RIGHT, graphics.background);
+			graphics.drawString(_("???? ???????? ????"), col1, y, TXT_RIGHT, graphics.background);
 		}
 		else
 		{
-			graphics.drawString(objective->description, col1, y, TXT_RIGHT, graphics.background);
+			graphics.drawString(_(objective->description), col1, y, TXT_RIGHT, graphics.background);
 		}
 
 		if (objective->currentValue < objective->targetValue)
@@ -263,7 +263,7 @@ void showMissionClear()
 			if (objective->targetValue == 1)
 			{
 				graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
-				graphics.drawString("Incomplete", col2, y, TXT_LEFT, graphics.background);
+				graphics.drawString(_("Incomplete"), col2, y, TXT_LEFT, graphics.background);
 			}
 			else
 			{
@@ -275,7 +275,7 @@ void showMissionClear()
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_LEFT, graphics.background);
+			graphics.drawString(_("Completed"), col2, y, TXT_LEFT, graphics.background);
 		}
 	}
 	
@@ -354,10 +354,10 @@ void showMissionClear()
 			}
 		}
 
-		sprintf(message, "%s - %.2d:%.2d:%.2d", "Mission Time", game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
+		sprintf(message, "%s - %.2d:%.2d:%.2d", _("Mission Time"), game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
 		graphics.drawString(message, 320, 420, true, graphics.screen);
 
-		while (SDL_GetTicks() < frameLimit){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks() + 16;
 	}
 
